@@ -4,10 +4,10 @@
 #include <QString>
 
 #define __VYM_NAME "VYM"
-#define __VYM_VERSION "1.99.0"
-#define __VYM_CODENAME "Codename: RC-1"
+#define __VYM_VERSION "2.0.3"
+#define __VYM_CODENAME "Codename: Production release"
 //#define __VYM_CODENAME "Codename: development version, not for production!"
-#define __VYM_BUILD_DATE "2011-09-21"
+#define __VYM_BUILD_DATE "2011-11-07"
 
 
 bool checkVersion(const QString &);
